Step 6: Blotting the Median Image — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »

# Step 6: Blotting the Median Image

The median image now gets blotted back to create median-cleaned images which can be compared directly with each input image to identify cosmic-rays.

`drizzlepac.ablot.` `blot`(data, outdata, configObj=None, wcsmap=<class drizzlepac.wcs_functions.WCSMap at 0x5249390>, editpars=False, **input_dict)

`drizzlepac.ablot.` `buildBlotParamDict`(configObj)

`drizzlepac.ablot.` `do_blot`(source, source_wcs, blot_wcs, exptime, coeffs=True, interp='poly5', sinscl=1.0, stepsize=10, wcsmap=None)

  Core functionality of performing the ‘blot’ operation to create a single blotted image from a single source image. All distortion information is assumed to be included in the WCS specification of the ‘output’ blotted image given in ‘blot_wcs’.

  Parameters :
  | source : Input numpy array of undistorted source image in units of ‘cps’. source_wcs : HSTWCS object representing source image WCS. blot_wcs : HSTWCS object representing the blotted image WCS. exptime :

`drizzlepac.ablot.` `getHelpAsString`()

  Return useful help from a file in the script directory called module.help

`drizzlepac.ablot.` `help`()

`drizzlepac.ablot.` `run`(configObj, wcsmap=None)

  Run the blot task based on parameters provided interactively by the user.

`drizzlepac.ablot.` `runBlot`(imageObjectList, output_wcs, configObj={}, wcsmap=<class drizzlepac.wcs_functions.WCSMap at 0x5249390>, procSteps=None)

`drizzlepac.ablot.` `run_blot`(imageObjectList, output_wcs, paramDict, wcsmap=<class drizzlepac.wcs_functions.WCSMap at 0x5249390>)

  Perform the blot operation on the list of images.

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »